@@ -15,9 +15,9 @@ class PlaylistOption(discord.SelectOption):
     @classmethod
     async def from_playlist(cls, playlist: PlaylistModel, bot: BotT, index: int):
         return cls(
-            label=f"{index + 1}. {playlist.name}",
+            label=f"{index + 1}. {await playlist.fetch_name()}",
             description=_("Tracks: {} || {} || {}").format(
-                len(playlist.tracks),
+                await playlist.size(),
                 await playlist.get_author_name(bot, mention=False),
                 await playlist.get_scope_name(bot, mention=False),
             ),
